Repository: mesos
Updated Branches:
  refs/heads/master 66bae088d -> a4e9695fe


http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/flags.cpp
----------------------------------------------------------------------
diff --git a/src/slave/flags.cpp b/src/slave/flags.cpp
index 943aaaf..b67ab9b 100644
--- a/src/slave/flags.cpp
+++ b/src/slave/flags.cpp
@@ -382,9 +382,9 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::executor_reregistration_timeout,
       "executor_reregistration_timeout",
-      "The timeout within which an executor is expected to re-register after\n"
+      "The timeout within which an executor is expected to reregister after\n"
       "the agent has restarted, before the agent considers it gone and shuts\n"
-      "it down. Note that currently, the agent will not re-register with the\n"
+      "it down. Note that currently, the agent will not reregister with the\n"
       "master until this timeout has elapsed (see MESOS-7539).",
       EXECUTOR_REREGISTRATION_TIMEOUT,
       [](const Duration& value) -> Option<Error> {

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/slave.cpp
----------------------------------------------------------------------
diff --git a/src/slave/slave.hpp b/src/slave/slave.hpp
index f161369..37f0361 100644
--- a/src/slave/slave.hpp
+++ b/src/slave/slave.hpp
@@ -277,7 +277,7 @@ public:
       const FrameworkID& frameworkId,
       const ExecutorID& executorId);
 
-  // Called when an executor re-registers with a recovering slave.
+  // Called when an executor reregisters with a recovering slave.
   // 'tasks' : Unacknowledged tasks (i.e., tasks that the executor
   //           driver never received an ACK for.)
   // 'updates' : Unacknowledged updates.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/task_status_update_manager.cpp
----------------------------------------------------------------------
diff --git a/src/slave/task_status_update_manager.cpp 
b/src/slave/task_status_update_manager.cpp
index 24d803d..f0cc502 100644
--- a/src/slave/task_status_update_manager.cpp
+++ b/src/slave/task_status_update_manager.cpp
@@ -272,7 +272,7 @@ Future<Nothing> TaskStatusUpdateManagerProcess::recover(
         // At the end of the replay, the stream is either terminated or
         // contains only unacknowledged, if any, pending updates. The
         // pending updates will be flushed after the slave
-        // re-registers with the master.
+        // reregisters with the master.
         if (stream->terminated) {
           cleanupStatusUpdateStream(task.id, framework.id);
         }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/api_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/api_tests.cpp b/src/tests/api_tests.cpp
index 9c172f7..e81d6ed 100644
--- a/src/tests/api_tests.cpp
+++ b/src/tests/api_tests.cpp
@@ -2178,14 +2178,14 @@ TEST_P_TEMP_DISABLED_ON_WINDOWS(MasterAPITest, 
GetRecoveredAgents)
   Future<SlaveReregisteredMessage> slaveReregisteredMessage =
     FUTURE_PROTOBUF(SlaveReregisteredMessage(), master.get()->pid, _);
 
-  // Start the agent to make it re-register with the master.
+  // Start the agent to make it reregister with the master.
   detector = master.get()->createDetector();
   slave = StartSlave(detector.get(), slaveFlags);
   ASSERT_SOME(slave);
 
   AWAIT_READY(slaveReregisteredMessage);
 
-  // After the agent has successfully re-registered with the master,
+  // After the agent has successfully reregistered with the master,
   // the `GetAgents.recovered_agents` field would be empty.
   {
     v1::master::Call v1Call;
@@ -3236,7 +3236,7 @@ TEST_P(MasterAPITest, FrameworksEvent)
     .WillRepeatedly(Return()); // Ignore future invocations.
 
   // Force a reconnection with the master. This should result in a
-  // 'FRAMEWORK_UPDATED' event when the scheduler re-registers with the master.
+  // 'FRAMEWORK_UPDATED' event when the scheduler reregisters with the master.
   mesos.reconnect();
 
   AWAIT_READY(disconnected);
@@ -4137,7 +4137,7 @@ TEST_P(MasterAPITest, MarkRegisteredAgentGone)
   AWAIT_EXPECT_RESPONSE_STATUS_EQ(http::OK().status, response);
   AWAIT_READY(shutdownMessage);
 
-  // The agent should not be able to re-register with
+  // The agent should not be able to reregister with
   // the master upon restart.
 
   slave.get()->terminate();

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/authentication_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/authentication_tests.cpp 
b/src/tests/authentication_tests.cpp
index 3c6124f..bd46cbc 100644
--- a/src/tests/authentication_tests.cpp
+++ b/src/tests/authentication_tests.cpp
@@ -693,7 +693,7 @@ TEST_F(AuthenticationTest, 
LeaderElectionDuringSlaveAuthentication)
 
 
 // This test verifies that if a scheduler fails over in the midst of
-// authentication it successfully re-authenticates and re-registers
+// authentication it successfully re-authenticates and reregisters
 // with the master when it comes back up.
 TEST_F(AuthenticationTest, SchedulerFailover)
 {

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/containerizer/docker_containerizer_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/docker_containerizer_tests.cpp 
b/src/tests/containerizer/docker_containerizer_tests.cpp
index 85e6f87..4e0bc06 100644
--- a/src/tests/containerizer/docker_containerizer_tests.cpp
+++ b/src/tests/containerizer/docker_containerizer_tests.cpp
@@ -2642,7 +2642,7 @@ TEST_F(DockerContainerizerTest, 
ROOT_DOCKER_Default_CMD_Args)
 
 // The slave is stopped before the first update for a task is received
 // from the executor. When it comes back up we make sure the executor
-// re-registers and the slave properly sends the update.
+// reregisters and the slave properly sends the update.
 TEST_F(DockerContainerizerTest, ROOT_DOCKER_SlaveRecoveryTaskContainer)
 {
   Try<Owned<cluster::Master>> master = StartMaster();
@@ -2762,7 +2762,7 @@ TEST_F(DockerContainerizerTest, 
ROOT_DOCKER_SlaveRecoveryTaskContainer)
   slave = StartSlave(detector.get(), dockerContainerizer.get(), flags);
   ASSERT_SOME(slave);
 
-  // Ensure the executor re-registers.
+  // Ensure the executor reregisters.
   AWAIT_READY(reregisterExecutorMessage);
 
   ReregisterExecutorMessage reregister;
@@ -2793,7 +2793,7 @@ TEST_F(DockerContainerizerTest, 
ROOT_DOCKER_SlaveRecoveryTaskContainer)
 
 // The slave is stopped before the first update for a task is received
 // from the executor. When it comes back up we make sure the executor
-// re-registers and the slave properly sends the update.
+// reregisters and the slave properly sends the update.
 //
 // TODO(benh): This test is currently disabled because the executor
 // inside the image mesosphere/test-executor does not properly set the
@@ -2947,7 +2947,7 @@ TEST_F(DockerContainerizerTest,
   slave = StartSlave(detector.get(), dockerContainerizer.get(), flags);
   ASSERT_SOME(slave);
 
-  // Ensure the executor re-registers.
+  // Ensure the executor reregisters.
   AWAIT_READY(reregisterExecutorMessage);
 
   ReregisterExecutorMessage reregister;

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/containerizer/docker_volume_isolator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/docker_volume_isolator_tests.cpp 
b/src/tests/containerizer/docker_volume_isolator_tests.cpp
index 9123cbe..36fffe2 100644
--- a/src/tests/containerizer/docker_volume_isolator_tests.cpp
+++ b/src/tests/containerizer/docker_volume_isolator_tests.cpp
@@ -625,7 +625,7 @@ TEST_F(DockerVolumeIsolatorTest, 
ROOT_CommandTaskNoRootfsSlaveRecovery)
   slave.get()->terminate();
 
   // Set up so we can wait until the new slave updates the container's
-  // resources (this occurs after the executor has re-registered).
+  // resources (this occurs after the executor has reregistered).
   Future<Nothing> update =
     FUTURE_DISPATCH(_, &MesosContainerizerProcess::update);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/containerizer/memory_pressure_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/memory_pressure_tests.cpp 
b/src/tests/containerizer/memory_pressure_tests.cpp
index 488051d..b5aa0a3 100644
--- a/src/tests/containerizer/memory_pressure_tests.cpp
+++ b/src/tests/containerizer/memory_pressure_tests.cpp
@@ -283,7 +283,7 @@ TEST_F(MemoryPressureMesosTest, CGROUPS_ROOT_SlaveRecovery)
   slave.get()->terminate();
 
   // Set up so we can wait until the new slave updates the container's
-  // resources (this occurs after the executor has re-registered).
+  // resources (this occurs after the executor has reregistered).
   Future<Nothing> update =
     FUTURE_DISPATCH(_, &MesosContainerizerProcess::update);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/containerizer/ports_isolator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/ports_isolator_tests.cpp 
b/src/tests/containerizer/ports_isolator_tests.cpp
index 0969cf5..c5b9f92 100644
--- a/src/tests/containerizer/ports_isolator_tests.cpp
+++ b/src/tests/containerizer/ports_isolator_tests.cpp
@@ -924,7 +924,7 @@ TEST_F(NetworkPortsIsolatorTest, ROOT_NC_RecoverBadTask)
   slave = StartSlave(detector.get(), flags);
   ASSERT_SOME(slave);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // Now force a ports check, which should terminate the nc command.
@@ -1051,7 +1051,7 @@ TEST_F(NetworkPortsIsolatorTest, ROOT_NC_RecoverGoodTask)
   slave = StartSlave(detector.get(), flags);
   ASSERT_SOME(slave);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // We should not get any status updates because the task should
@@ -1365,7 +1365,7 @@ TEST_F(NetworkPortsIsolatorTest, 
ROOT_NC_RecoverNestedBadTask)
 
   slave.get()->start();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<Event::Update> updateFinished;
@@ -1542,7 +1542,7 @@ TEST_F(NetworkPortsIsolatorTest, 
ROOT_NC_RecoverNestedGoodTask)
 
   slave.get()->start();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // We expect that the task will continue to run, so the health check

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/containerizer/xfs_quota_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/xfs_quota_tests.cpp 
b/src/tests/containerizer/xfs_quota_tests.cpp
index ce69c88..64c3e1c 100644
--- a/src/tests/containerizer/xfs_quota_tests.cpp
+++ b/src/tests/containerizer/xfs_quota_tests.cpp
@@ -944,7 +944,7 @@ TEST_F(ROOT_XFS_QuotaTest, CheckpointRecovery)
   slave = StartSlave(detector.get(), flags);
   ASSERT_SOME(slave);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<ResourceUsage> usage2 =
@@ -1070,7 +1070,7 @@ TEST_F(ROOT_XFS_QuotaTest, RecoverOldContainers)
   slave = StartSlave(detector.get(), CreateSlaveFlags());
   ASSERT_SOME(slave);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   {

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/disk_quota_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/disk_quota_tests.cpp b/src/tests/disk_quota_tests.cpp
index db53108..d2416e1 100644
--- a/src/tests/disk_quota_tests.cpp
+++ b/src/tests/disk_quota_tests.cpp
@@ -727,7 +727,7 @@ TEST_F(DiskQuotaTest, SlaveRecovery)
   // Wait for slave to schedule reregister timeout.
   Clock::settle();
 
-  // Ensure the executor re-registers before completing recovery.
+  // Ensure the executor reregisters before completing recovery.
   AWAIT_READY(reregisterExecutorMessage);
 
   // Ensure the slave considers itself recovered.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/fault_tolerance_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/fault_tolerance_tests.cpp 
b/src/tests/fault_tolerance_tests.cpp
index 64a8653..91cc9a2 100644
--- a/src/tests/fault_tolerance_tests.cpp
+++ b/src/tests/fault_tolerance_tests.cpp
@@ -106,7 +106,7 @@ class FaultToleranceTest : public MesosTest {};
 // This test ensures that a framework connecting with a
 // failed over master gets a registered callback.
 // Note that this behavior might change in the future and
-// the scheduler might receive a re-registered callback.
+// the scheduler might receive a reregistered callback.
 TEST_F_TEMP_DISABLED_ON_WINDOWS(FaultToleranceTest, MasterFailover)
 {
   Try<Owned<cluster::Master>> master = StartMaster();
@@ -499,7 +499,7 @@ TEST_F(FaultToleranceTest, SchedulerFailover)
 }
 
 
-// This test verifies that a framework attempting to re-register
+// This test verifies that a framework attempting to reregister
 // after its failover timeout has elapsed is disallowed.
 TEST_F(FaultToleranceTest, SchedulerReregisterAfterFailoverTimeout)
 {
@@ -588,7 +588,7 @@ TEST_F(FaultToleranceTest, 
SchedulerReregisterAfterFailoverTimeout)
 }
 
 
-// This test verifies that a framework attempting to re-register
+// This test verifies that a framework attempting to reregister
 // after it is unregistered is disallowed.
 TEST_F(FaultToleranceTest, SchedulerReregisterAfterUnregistration)
 {
@@ -785,7 +785,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(
 }
 
 
-// This test ensures framework re-registers with master after failover.
+// This test ensures framework reregisters with master after failover.
 // Previous offers are rescinded and re-offered to the framework after
 // re-registration.
 TEST_F_TEMP_DISABLED_ON_WINDOWS(FaultToleranceTest, FrameworkReregister)
@@ -871,7 +871,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(FaultToleranceTest, 
FrameworkReregister)
   Clock::advance(masterFlags.allocation_interval);
   Clock::resume();
 
-  // The re-registered framework should get offers.
+  // The reregistered framework should get offers.
   AWAIT_READY(resourceOffers2);
 
   // Check that the framework is displayed correctly in the "/state" endpoint.
@@ -1228,7 +1228,7 @@ TEST_F(FaultToleranceTest, 
ReregisterFrameworkExitedExecutor)
 
   slaveDetector.appoint(master.get()->pid);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // Allow the executor exited message and drop the status update,
@@ -1549,7 +1549,7 @@ TEST_F(FaultToleranceTest, 
SchedulerFailoverFrameworkToExecutorMessage)
 
 // This test verifies that a partitioned framework that still
 // thinks it is registered with the master cannot kill a task because
-// the master has re-registered another instance of the framework.
+// the master has reregistered another instance of the framework.
 // What this test does:
 // 1. Launch a master, slave and scheduler.
 // 2. Scheduler launches a task.
@@ -2017,7 +2017,7 @@ TEST_F(FaultToleranceTest, SplitBrainMasters)
 }
 
 
-// This test verifies that when a framework re-registers with updated
+// This test verifies that when a framework reregisters with updated
 // FrameworkInfo, it gets updated in the master. The steps involved
 // are:
 //   1. Launch a master, slave and scheduler.
@@ -2162,7 +2162,7 @@ TEST_F(FaultToleranceTest, 
UpdateFrameworkInfoOnSchedulerFailover)
 }
 
 
-// This test verifies that when a framework re-registers after master
+// This test verifies that when a framework reregisters after master
 // failover with an updated FrameworkInfo, the updated FrameworkInfo
 // is reflected in the master.
 TEST_F_TEMP_DISABLED_ON_WINDOWS(
@@ -2232,9 +2232,9 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(
   driver1.stop();
   driver1.join();
 
-  // Restart master; ensure the agent re-registers before the second
+  // Restart master; ensure the agent reregisters before the second
   // scheduler connects. This ensures the first framework's
-  // FrameworkInfo is recovered from the re-registering agent.
+  // FrameworkInfo is recovered from the reregistering agent.
   Future<SlaveReregisteredMessage> slaveReregistered = FUTURE_PROTOBUF(
       SlaveReregisteredMessage(), _, slave.get()->pid);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/fetcher_cache_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/fetcher_cache_tests.cpp 
b/src/tests/fetcher_cache_tests.cpp
index 4d9e5d8..98aae20 100644
--- a/src/tests/fetcher_cache_tests.cpp
+++ b/src/tests/fetcher_cache_tests.cpp
@@ -1349,7 +1349,7 @@ TEST_F(FetcherCacheHttpTest, DISABLED_HttpCachedRecovery)
   containerizer.reset(_containerizer.get());
 
   // Set up so we can wait until the new slave updates the container's
-  // resources (this occurs after the executor has re-registered).
+  // resources (this occurs after the executor has reregistered).
   Future<Nothing> update =
     FUTURE_DISPATCH(_, &MesosContainerizerProcess::update);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/gc_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/gc_tests.cpp b/src/tests/gc_tests.cpp
index bff3c05..619ed22 100644
--- a/src/tests/gc_tests.cpp
+++ b/src/tests/gc_tests.cpp
@@ -328,7 +328,7 @@ TEST_F(GarbageCollectorIntegrationTest, Restart)
     .WillRepeatedly(Return()); // Ignore subsequent offers.
 
   // Ignore offerRescinded calls. The scheduler might receive it
-  // because the slave might re-register due to ping timeout.
+  // because the slave might reregister due to ping timeout.
   EXPECT_CALL(sched, offerRescinded(_, _))
     .WillRepeatedly(Return());
 
@@ -556,7 +556,7 @@ TEST_F(GarbageCollectorIntegrationTest, ExitedExecutor)
     .WillRepeatedly(Return()); // Ignore subsequent offers.
 
   // Ignore offerRescinded calls. The scheduler might receive it
-  // because the slave might re-register due to ping timeout.
+  // because the slave might reregister due to ping timeout.
   EXPECT_CALL(sched, offerRescinded(_, _))
     .WillRepeatedly(Return());
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/master_allocator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_allocator_tests.cpp 
b/src/tests/master_allocator_tests.cpp
index 43f1c71..1ceb8e8 100644
--- a/src/tests/master_allocator_tests.cpp
+++ b/src/tests/master_allocator_tests.cpp
@@ -1650,7 +1650,7 @@ TYPED_TEST(MasterAllocatorTest, SlaveReregistersFirst)
                       FutureSatisfy(&addSlave)));
 
     // Expect the framework to be added but to be inactive when the
-    // agent re-registers, until the framework re-registers below.
+    // agent reregisters, until the framework reregisters below.
     Future<Nothing> addFramework;
     EXPECT_CALL(allocator2, addFramework(_, _, _, false, _))
       .WillOnce(DoAll(InvokeAddFramework(&allocator2),
@@ -1673,7 +1673,7 @@ TYPED_TEST(MasterAllocatorTest, SlaveReregistersFirst)
     EXPECT_CALL(sched, registered(&driver, _, _));
 
     // Because the framework was re-added above, we expect to only
-    // activate the framework when it re-registers.
+    // activate the framework when it reregisters.
     EXPECT_CALL(allocator2, addFramework(_, _, _, _, _))
       .Times(0);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/master_authorization_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_authorization_tests.cpp 
b/src/tests/master_authorization_tests.cpp
index 8e526fc..80b9d49 100644
--- a/src/tests/master_authorization_tests.cpp
+++ b/src/tests/master_authorization_tests.cpp
@@ -1137,7 +1137,7 @@ TEST_F(MasterAuthorizationTest, DuplicateRegistration)
 // This test verifies that an authentication request that comes from
 // the same instance of the framework (e.g., ZK blip) before
 // 'Master::_reregisterFramework()' from an earlier attempt, causes
-// the master to successfully re-register the framework.
+// the master to successfully reregister the framework.
 TEST_F(MasterAuthorizationTest, DuplicateReregistration)
 {
   MockAuthorizer authorizer;
@@ -1304,7 +1304,7 @@ TEST_F(MasterAuthorizationTest, 
FrameworkRemovedBeforeReregistration)
 
   EXPECT_CALL(sched, disconnected(&driver));
 
-  // Framework should not be re-registered.
+  // Framework should not be reregistered.
   EXPECT_CALL(sched, reregistered(&driver, _))
     .Times(0);
 
@@ -2173,7 +2173,7 @@ TYPED_TEST(MasterAuthorizerTest, FilterRolesEndpoint)
 // default users are allowed to to view high level frameworks, but
 // only one is allowed to view the tasks. Although the tasks are
 // "orphaned" (in the sense that their framework has not yet
-// re-registered), they are now reported under the "tasks" key.
+// reregistered), they are now reported under the "tasks" key.
 TYPED_TEST(MasterAuthorizerTest, FilterOrphanedTasks)
 {
   ACLs acls;
@@ -2280,7 +2280,7 @@ TYPED_TEST(MasterAuthorizerTest, FilterOrphanedTasks)
   // Simulate a new master detected event to the slave.
   detector.appoint(master.get()->pid);
 
-  // The framework will not re-register with the new master as the
+  // The framework will not reregister with the new master as the
   // scheduler is bound to the old master pid.
 
   AWAIT_READY(slaveReregisteredMessage);
@@ -2418,7 +2418,7 @@ TEST_F(MasterAuthorizationTest, 
UnauthorizedToRegisterAgent)
 
 
 // This test verifies that an agent authorized to register can be
-// unauthorized to re-register due to master ACL change (after failover).
+// unauthorized to reregister due to master ACL change (after failover).
 TEST_F(MasterAuthorizationTest, UnauthorizedToReregisterAgent)
 {
   // Set up ACLs so that the agent can register.
@@ -2447,7 +2447,7 @@ TEST_F(MasterAuthorizationTest, 
UnauthorizedToReregisterAgent)
   // Master fails over.
   master->reset();
 
-  // The new master doesn't allow this agent principal to re-register.
+  // The new master doesn't allow this agent principal to reregister.
   acl->mutable_agents()->set_type(ACL::Entity::NONE);
   flags.acls = acls;
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/master_slave_reconciliation_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_slave_reconciliation_tests.cpp 
b/src/tests/master_slave_reconciliation_tests.cpp
index 0541aa5..6bb4263 100644
--- a/src/tests/master_slave_reconciliation_tests.cpp
+++ b/src/tests/master_slave_reconciliation_tests.cpp
@@ -72,11 +72,11 @@ namespace tests {
 class MasterSlaveReconciliationTest : public MesosTest {};
 
 
-// This test verifies that a re-registering slave sends the terminal
+// This test verifies that a reregistering slave sends the terminal
 // unacknowledged tasks for a terminal executor. This is required
 // for the master to correctly reconcile its view with the slave's
 // view of tasks. This test drops a terminal update to the master
-// and then forces the slave to re-register.
+// and then forces the slave to reregister.
 TEST_F(MasterSlaveReconciliationTest, SlaveReregisterTerminatedExecutor)
 {
   Try<Owned<cluster::Master>> master = StartMaster();
@@ -167,7 +167,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterTerminatedExecutor)
 
 
 // This test verifies that the master reconciles non-partition-aware
-// tasks that are missing from a re-registering slave. In this case,
+// tasks that are missing from a reregistering slave. In this case,
 // we drop the RunTaskMessage, so the slave should send TASK_LOST.
 TEST_F(MasterSlaveReconciliationTest, ReconcileLostTask)
 {
@@ -258,7 +258,7 @@ TEST_F(MasterSlaveReconciliationTest, ReconcileLostTask)
 
 
 // This test verifies that the master reconciles partition-aware tasks
-// that are missing from a re-registering slave. In this case, we drop
+// that are missing from a reregistering slave. In this case, we drop
 // the RunTaskMessage, so the slave should send TASK_DROPPED.
 TEST_F(MasterSlaveReconciliationTest, ReconcileDroppedTask)
 {
@@ -353,7 +353,7 @@ TEST_F(MasterSlaveReconciliationTest, ReconcileDroppedTask)
 
 
 // This test verifies that the master reconciles tasks that are
-// missing from a re-registering slave. In this case, we trigger
+// missing from a reregistering slave. In this case, we trigger
 // a race between the slave re-registration message and the launch
 // message. There should be no TASK_LOST / TASK_DROPPED.
 // This was motivated by MESOS-1696.
@@ -485,7 +485,7 @@ TEST_F(MasterSlaveReconciliationTest, ReconcileRace)
 
 
 // This test verifies that the slave reports pending tasks when
-// re-registering, otherwise the master will report them as being
+// reregistering, otherwise the master will report them as being
 // lost.
 TEST_F(MasterSlaveReconciliationTest, SlaveReregisterPendingTask)
 {
@@ -550,7 +550,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterPendingTask)
 }
 
 
-// This test verifies that when the slave re-registers, the master
+// This test verifies that when the slave reregisters, the master
 // does not send TASK_LOST update for a task that has reached terminal
 // state but is waiting for an acknowledgement.
 TEST_F(MasterSlaveReconciliationTest, SlaveReregisterTerminalTask)
@@ -596,7 +596,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterTerminalTask)
     .WillOnce(SendStatusUpdateFromTask(TASK_FINISHED));
 
   // Drop the status update from slave to the master, so that
-  // the slave has a pending terminal update when it re-registers.
+  // the slave has a pending terminal update when it reregisters.
   DROP_PROTOBUF(StatusUpdateMessage(), _, master.get()->pid);
 
   Future<Nothing> _statusUpdate = FUTURE_DISPATCH(_, &Slave::_statusUpdate);
@@ -620,7 +620,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterTerminalTask)
   AWAIT_READY(slaveReregisteredMessage);
 
   // The master should not send a TASK_LOST after the slave
-  // re-registers. We check this by calling Clock::settle() so that
+  // reregisters. We check this by calling Clock::settle() so that
   // the only update the scheduler receives is the retried
   // TASK_FINISHED update.
   // NOTE: The task status update manager resends the status update
@@ -639,7 +639,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterTerminalTask)
 }
 
 
-// This test verifies that when the slave re-registers, we correctly
+// This test verifies that when the slave reregisters, we correctly
 // send the information about actively running frameworks.
 TEST_F(MasterSlaveReconciliationTest, SlaveReregisterFrameworks)
 {
@@ -715,7 +715,7 @@ TEST_F(MasterSlaveReconciliationTest, 
SlaveReregisterFrameworks)
 }
 
 
-// This test verifies that when re-registering, the slave sends the
+// This test verifies that when reregistering, the slave sends the
 // executor ID of a non-command executor task, but not the one of a
 // command executor task. We then check that the master's API has
 // task IDs absent only for the command executor case.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/master_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_tests.cpp b/src/tests/master_tests.cpp
index 24b7f57..9095651 100644
--- a/src/tests/master_tests.cpp
+++ b/src/tests/master_tests.cpp
@@ -1342,7 +1342,7 @@ TEST_F(MasterTest, MasterInfoOnReElection)
   Clock::advance(masterFlags.allocation_interval);
   Clock::resume();
 
-  // The re-registered framework should get offers.
+  // The reregistered framework should get offers.
   AWAIT_READY(resourceOffers2);
 
   driver.stop();
@@ -2915,9 +2915,9 @@ TEST_F(MasterTest, RegistryUpdateAfterMasterFailover)
 
 
 // This test ensures that when a slave is recovered from the registry
-// but does not re-register with the master, it is marked unreachable
+// but does not reregister with the master, it is marked unreachable
 // in the registry, the framework is informed that the slave is lost,
-// and the slave is allowed to re-register.
+// and the slave is allowed to reregister.
 TEST_F(MasterTest, RecoveredSlaveCanReregister)
 {
   // Step 1: Start a master.
@@ -2983,11 +2983,11 @@ TEST_F(MasterTest, RecoveredSlaveCanReregister)
 
   Clock::resume();
 
-  // Step 7: Ensure the slave can re-register.
+  // Step 7: Ensure the slave can reregister.
   Future<SlaveReregisteredMessage> slaveReregisteredMessage =
     FUTURE_PROTOBUF(SlaveReregisteredMessage(), master.get()->pid, _);
 
-  // Expect a resource offer from the re-registered slave.
+  // Expect a resource offer from the reregistered slave.
   Future<Nothing> offers;
   EXPECT_CALL(sched, resourceOffers(&driver, _))
     .WillOnce(FutureSatisfy(&offers));
@@ -3073,14 +3073,14 @@ TEST_F(MasterTest, UnreachableTaskAfterFailover)
   AWAIT_READY(statusUpdateAck2);
 
   // Step 4: Simulate master failover. We leave the slave without a
-  // master so it does not attempt to re-register.
+  // master so it does not attempt to reregister.
   slaveDetector.appoint(None());
 
   master->reset();
   master = StartMaster(masterFlags);
   ASSERT_SOME(master);
 
-  // Cause the scheduler to re-register with the master.
+  // Cause the scheduler to reregister with the master.
   Future<Nothing> disconnected;
   EXPECT_CALL(sched, disconnected(&driver))
     .WillOnce(FutureSatisfy(&disconnected));
@@ -3125,7 +3125,7 @@ TEST_F(MasterTest, UnreachableTaskAfterFailover)
   EXPECT_EQ(TaskStatus::REASON_RECONCILIATION, reconcileUpdate1->reason());
   EXPECT_EQ(unreachableTime, reconcileUpdate1->unreachable_time());
 
-  // Cause the slave to re-register with the master.
+  // Cause the slave to reregister with the master.
   Future<SlaveReregisteredMessage> slaveReregisteredMessage =
     FUTURE_PROTOBUF(SlaveReregisteredMessage(), _, _);
 
@@ -3241,7 +3241,7 @@ TEST_F(MasterTest, RateLimitRecoveredSlaveRemoval)
 
 
 // This test ensures that slave removals that get scheduled during
-// master recovery can be canceled if the slave re-registers.
+// master recovery can be canceled if the slave reregisters.
 TEST_F(MasterTest, CancelRecoveredSlaveRemoval)
 {
   // Start a master.
@@ -3310,7 +3310,7 @@ TEST_F(MasterTest, CancelRecoveredSlaveRemoval)
   Clock::settle();
   ASSERT_TRUE(slaveLost.isPending());
 
-  // Ignore resource offers from the re-registered slave.
+  // Ignore resource offers from the reregistered slave.
   EXPECT_CALL(sched, resourceOffers(&driver, _))
     .WillRepeatedly(Return());
 
@@ -3336,7 +3336,7 @@ TEST_F(MasterTest, CancelRecoveredSlaveRemoval)
 
 
 // This test ensures that when a slave is recovered from the registry
-// and re-registers with the master, it is *not* removed after the
+// and reregisters with the master, it is *not* removed after the
 // re-registration timeout elapses.
 TEST_F(MasterTest, RecoveredSlaveReregisters)
 {
@@ -3378,7 +3378,7 @@ TEST_F(MasterTest, RecoveredSlaveReregisters)
     .WillOnce(FutureSatisfy(&registered));
 
   // Ignore all offer related calls. The scheduler might receive
-  // offerRescinded calls because the slave might re-register due to
+  // offerRescinded calls because the slave might reregister due to
   // ping timeout.
   EXPECT_CALL(sched, resourceOffers(&driver, _))
     .WillRepeatedly(Return());
@@ -3598,7 +3598,7 @@ TEST_F(MasterZooKeeperTest, MasterInfoAddress)
 
 
 // This test ensures that when a master fails over, tasks that belong
-// to frameworks that have not re-registered will be reported in the
+// to frameworks that have not reregistered will be reported in the
 // "/state" endpoint. The framework itself should have the "recovered"
 // field set to true.
 TEST_F(MasterTest, RecoveredFramework)
@@ -3764,7 +3764,7 @@ TEST_F(MasterTest, RecoveredFramework)
   Future<FrameworkRegisteredMessage> frameworkRegisteredMessage =
     FUTURE_PROTOBUF(FrameworkRegisteredMessage(), _, _);
 
-  // Advance the clock to let the framework re-register with the master.
+  // Advance the clock to let the framework reregister with the master.
   Clock::advance(Seconds(1));
   Clock::settle();
   Clock::resume();
@@ -3817,7 +3817,7 @@ TEST_F(MasterTest, RecoveredFramework)
 }
 
 
-// This test verifies that a framework that has not yet re-registered
+// This test verifies that a framework that has not yet reregistered
 // after a master failover doesn't show up multiple times in
 // "frameworks" when querying "/state" or "/frameworks" endpoints. This
 // is to catch any regressions for MESOS-4973 and MESOS-6461.
@@ -5245,14 +5245,14 @@ TEST_F(MasterTest, RecoveredSlaves)
   Future<SlaveReregisteredMessage> slaveReregisteredMessage =
     FUTURE_PROTOBUF(SlaveReregisteredMessage(), master.get()->pid, _);
 
-  // Start the agent to make it re-register with the master.
+  // Start the agent to make it reregister with the master.
   detector = master.get()->createDetector();
   slave = StartSlave(detector.get(), slaveFlags);
   ASSERT_SOME(slave);
 
   AWAIT_READY(slaveReregisteredMessage);
 
-  // After the agent has successfully re-registered with the master, the
+  // After the agent has successfully reregistered with the master, the
   // `recovered_slaves` field would be empty in both `/state` and `slave`
   // endpoints.
 
@@ -6133,7 +6133,7 @@ TEST_F(MasterTest, DuplicatedSlaveIdWhenSlaveReregister)
   Future<SlaveReregisteredMessage> slaveReregisteredMessage1 =
       FUTURE_PROTOBUF(SlaveReregisteredMessage(), master.get()->pid, _);
 
-  // Now let the first slave re-register.
+  // Now let the first slave reregister.
   slaveDetector1.appoint(master.get()->pid);
 
   // If both the slaves get the same SlaveID, the re-registration would
@@ -6978,7 +6978,7 @@ TEST_F(MasterTest, DISABLED_RecoverResourcesOrphanedTask)
 
   AWAIT_READY(disconnected);
 
-  // Have the agent re-register with the master.
+  // Have the agent reregister with the master.
   detector.appoint(master.get()->pid);
 
   // Ensure re-registration is complete.
@@ -7070,7 +7070,7 @@ TEST_F(MasterTest, DISABLED_RecoverResourcesOrphanedTask)
 
 // This test checks that the "/state" endpoint displays the correct
 // information when the master fails over and an agent running one of
-// the framework's tasks re-registers before the framework does.
+// the framework's tasks reregisters before the framework does.
 TEST_F(MasterTest, FailoverAgentReregisterFirst)
 {
   master::Flags masterFlags = CreateMasterFlags();
@@ -7131,7 +7131,7 @@ TEST_F(MasterTest, FailoverAgentReregisterFirst)
   AWAIT_READY(statusUpdateAck2);
 
   // Simulate master failover. We leave the scheduler without a master
-  // so it does not attempt to re-register yet.
+  // so it does not attempt to reregister yet.
   EXPECT_CALL(sched, disconnected(&driver));
 
   schedDetector.appoint(None());
@@ -7149,7 +7149,7 @@ TEST_F(MasterTest, FailoverAgentReregisterFirst)
   AWAIT_READY(slaveReregisteredMessage);
 
   // Check the master's "/state" endpoint. Because the slave has
-  // re-registered, the master should know about the framework but
+  // reregistered, the master should know about the framework but
   // view it as disconnected and inactive.
   {
     Future<Response> response = process::http::get(
@@ -7192,7 +7192,7 @@ TEST_F(MasterTest, FailoverAgentReregisterFirst)
     EXPECT_TRUE(completedFrameworks.values.empty());
   }
 
-  // Cause the scheduler to re-register. We pause the clock to ensure
+  // Cause the scheduler to reregister. We pause the clock to ensure
   // the re-registration time is predictable. We get a "registered"
   // callback in the scheduler driver because of MESOS-786.
   Future<Nothing> registered;
@@ -7273,7 +7273,7 @@ TEST_F(MasterTest, FailoverAgentReregisterFirst)
 
 
 // In this test, an agent restarts, responds to pings, but does not
-// re-register with the master; the master should mark the agent
+// reregister with the master; the master should mark the agent
 // unreachable after waiting for `agent_reregister_timeout`. In
 // practice, this typically happens because agent recovery hangs; to
 // simplify the test case, we instead drop the agent -> master
@@ -7303,7 +7303,7 @@ TEST_F(MasterTest, AgentRestartNoReregister)
 
   // We use the same UPID when we restart the agent below, so that the
   // agent continues to receive pings from the master before it
-  // successfully re-registers.
+  // successfully reregisters.
   const string agentPid = "agent";
 
   Try<Owned<cluster::Slave>> slave =
@@ -7386,7 +7386,7 @@ TEST_F(MasterTest, AgentRestartNoReregister)
   slave = StartSlave(&detector, containerizer.get(), agentPid, agentFlags);
   ASSERT_SOME(slave);
 
-  // Wait for the executor to re-register.
+  // Wait for the executor to reregister.
   AWAIT_READY(reregisterExecutorMessage);
 
   // The agent waits for the executor reregister timeout to expire,
@@ -7394,7 +7394,7 @@ TEST_F(MasterTest, AgentRestartNoReregister)
   Clock::advance(agentFlags.executor_reregistration_timeout);
   Clock::settle();
 
-  // Agent will try to re-register after completing recovery; prevent
+  // Agent will try to reregister after completing recovery; prevent
   // this from succeeding by dropping the re-reregistration message.
   Clock::advance(agentFlags.registration_backoff_factor);
   AWAIT_READY(reregisterSlave1);
@@ -7479,7 +7479,7 @@ TEST_F(MasterTest, AgentRestartNoReregister)
 }
 
 
-// When removing agents that haven't re-registered after a socket
+// When removing agents that haven't reregistered after a socket
 // error (see notes in `AgentRestartNoReregister`) above, this test
 // checks that the master respects the agent removal rate limit.
 TEST_F(MasterTest, AgentRestartNoReregisterRateLimit)
@@ -7505,7 +7505,7 @@ TEST_F(MasterTest, AgentRestartNoReregisterRateLimit)
 
   // We use the same UPID when we restart the agent below, so that the
   // agent continues to receive pings from the master before it
-  // successfully re-registers.
+  // successfully reregisters.
   const string agentPid = "agent";
 
   Try<Owned<cluster::Slave>> slave =
@@ -7548,7 +7548,7 @@ TEST_F(MasterTest, AgentRestartNoReregisterRateLimit)
   slave = StartSlave(&detector, containerizer.get(), agentPid, agentFlags);
   ASSERT_SOME(slave);
 
-  // Agent will try to re-register after completing recovery; prevent
+  // Agent will try to reregister after completing recovery; prevent
   // this from succeeding by dropping the re-reregistration message.
   Clock::advance(agentFlags.registration_backoff_factor);
   AWAIT_READY(reregisterSlave);
@@ -8263,7 +8263,7 @@ TEST_F(MasterTest, RegistrationWithoutRequiredAgentDomain)
 
 
 // This test checks that if the `--require_agent_domain` flag is set and
-// the agent does not have a domain configured when trying to re-register,
+// the agent does not have a domain configured when trying to reregister,
 // the re-registration attempt will fail.
 TEST_F(MasterTest, ReregistrationWithoutRequiredAgentDomain)
 {
@@ -8290,7 +8290,7 @@ TEST_F(MasterTest, 
ReregistrationWithoutRequiredAgentDomain)
 
   AWAIT_READY(slaveRegisteredMessage);
 
-  // Shut down slave and re-register without domain. We do this by
+  // Shut down slave and reregister without domain. We do this by
   // intercepting the `ReregisterSlaveMessage` and erasing the domain
   // before passing it on to the master.
   Future<ReregisterSlaveMessage> reregisterSlaveMessage =
@@ -8320,7 +8320,7 @@ TEST_F(MasterTest, 
ReregistrationWithoutRequiredAgentDomain)
 
 
 // This test checks that if the agent is configured with a domain but
-// the master is not, the agent is not allowed to re-register. This
+// the master is not, the agent is not allowed to reregister. This
 // might happen if the leading master is configured with a domain but
 // one of the standby masters is not, and then the leader fails over.
 TEST_F(MasterTest, AgentDomainMismatchOnReregister)
@@ -8358,7 +8358,7 @@ TEST_F(MasterTest, AgentDomainMismatchOnReregister)
   Future<ReregisterSlaveMessage> reregisterSlaveMessage =
     FUTURE_PROTOBUF(ReregisterSlaveMessage(), _, _);
 
-  // If the agent is allowed to re-register, the master will update
+  // If the agent is allowed to reregister, the master will update
   // the registry. The agent should not be allowed to register, so we
   // expect that no registrar operations will be observed.
   EXPECT_CALL(*master.get()->registrar, apply(_))
@@ -8428,7 +8428,7 @@ TEST_F(MasterTest, IgnoreOldAgentRegistration)
 }
 
 
-// Check that the master does not allow old Mesos agents to re-register.
+// Check that the master does not allow old Mesos agents to reregister.
 // We do this by intercepting the agent's `ReregisterSlaveMessage` and
 // then re-sending it with a tweaked version number.
 TEST_F(MasterTest, IgnoreOldAgentReregistration)
@@ -8456,7 +8456,7 @@ TEST_F(MasterTest, IgnoreOldAgentReregistration)
     DROP_PROTOBUF(ReregisterSlaveMessage(), _, _);
 
   // Simulate a new master detected event on the slave,
-  // so that the slave will attempt to re-register.
+  // so that the slave will attempt to reregister.
   detector.appoint(master.get()->pid);
 
   Clock::settle();
@@ -8901,7 +8901,7 @@ TEST_F(MasterTest, OperationUpdateDuringFailover)
   // Drop the operation update for the finished operation.
   // As we fail over the master immediately afterwards, we expect
   // that the operation update will be part of the agent's
-  // `UPDATE_STATE` message when re-registering with the master.
+  // `UPDATE_STATE` message when reregistering with the master.
   Future<UpdateOperationStatusMessage> updateOperationStatusMessage =
     DROP_PROTOBUF(UpdateOperationStatusMessage(), _, _);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/oversubscription_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/oversubscription_tests.cpp 
b/src/tests/oversubscription_tests.cpp
index 41c1178..5644057 100644
--- a/src/tests/oversubscription_tests.cpp
+++ b/src/tests/oversubscription_tests.cpp
@@ -860,7 +860,7 @@ TEST_F(OversubscriptionTest, QoSFetchResourceUsage)
 
 
 // Ensures the slave forwards the estimation whenever receiving
-// a registered or re-registered message from the master, even
+// a registered or reregistered message from the master, even
 // if the total oversubscribable resources does not change.
 TEST_F(OversubscriptionTest, Reregistration)
 {
@@ -1191,7 +1191,7 @@ TEST_F(OversubscriptionTest, 
QoSCorrectionKillPartitionAware)
 }
 
 
-// This test verifies that when a framework re-registers with updated
+// This test verifies that when a framework reregisters with updated
 // FrameworkInfo, it gets updated in the allocator. The steps involved
 // are:
 //   1. Launch a master, slave and scheduler.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/partition_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/partition_tests.cpp b/src/tests/partition_tests.cpp
index a9036a1..9138e5c 100644
--- a/src/tests/partition_tests.cpp
+++ b/src/tests/partition_tests.cpp
@@ -1066,7 +1066,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(
 // This test causes a slave to be partitioned while it is running a
 // task for a PARTITION_AWARE framework. The scheduler is shutdown
 // before the partition heals; the task should be shutdown after the
-// agent re-registers.
+// agent reregisters.
 TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, PartitionedSlaveOrphanedTask)
 {
   Clock::pause();
@@ -1185,7 +1185,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
PartitionedSlaveOrphanedTask)
   driver.stop();
   driver.join();
 
-  // Before the agent re-registers, check how `task` is displayed by
+  // Before the agent reregisters, check how `task` is displayed by
   // the master's "/state" endpoint.
   {
     Future<Response> response = process::http::get(
@@ -1240,7 +1240,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
PartitionedSlaveOrphanedTask)
         completedTask.values["state"].as<JSON::String>().value);
   }
 
-  // Cause the slave to re-register with the master; the master should
+  // Cause the slave to reregister with the master; the master should
   // send a `ShutdownFrameworkMessage` to the slave.
   Future<SlaveReregisteredMessage> slaveReregistered = FUTURE_PROTOBUF(
       SlaveReregisteredMessage(), master.get()->pid, slave.get()->pid);
@@ -1256,7 +1256,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
PartitionedSlaveOrphanedTask)
 
   Clock::resume();
 
-  // After the agent re-registers, check how `task` is displayed by
+  // After the agent reregisters, check how `task` is displayed by
   // the master's "/state" endpoint.
   {
     Future<Response> response = process::http::get(
@@ -3251,7 +3251,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
RegistryGcRace)
 
   AWAIT_READY(slaveLost1);
 
-  // `slave1` will try to re-register below when we advance the clock.
+  // `slave1` will try to reregister below when we advance the clock.
   // Prevent this by dropping all future messages from it.
   DROP_MESSAGES(_, slave1.get()->pid, _);
 
@@ -3288,7 +3288,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
RegistryGcRace)
 
   AWAIT_READY(slaveLost2);
 
-  // `slave2` will try to re-register below when we advance the clock.
+  // `slave2` will try to reregister below when we advance the clock.
   // Prevent this by dropping the next `ReregisterSlaveMessage` from it.
   Future<Message> reregisterSlave2 =
     DROP_MESSAGE(Eq(ReregisterSlaveMessage().GetTypeName()),
@@ -3332,7 +3332,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(PartitionTest, 
RegistryGcRace)
   Clock::advance(agentFlags2.registration_backoff_factor);
   AWAIT_READY(reregisterSlave2);
 
-  // `slave3` will try to re-register below when we advance the clock.
+  // `slave3` will try to reregister below when we advance the clock.
   // Prevent this by dropping all future messages from it.
   DROP_MESSAGES(_, slave3.get()->pid, _);
 
@@ -3581,7 +3581,7 @@ class OneWayPartitionTest : public MesosTest {};
 
 // This test verifies that if the master --> slave socket closes and
 // the slave is unaware of it (i.e., one-way network partition), slave
-// will re-register with the master.
+// will reregister with the master.
 TEST_F_TEMP_DISABLED_ON_WINDOWS(OneWayPartitionTest, MasterToSlave)
 {
   // Pausing the clock ensures that the agent does not attempt to
@@ -3632,7 +3632,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(OneWayPartitionTest, 
MasterToSlave)
   AWAIT_READY(ping);
   EXPECT_FALSE(ping->connected());
 
-  // Slave should re-register.
+  // Slave should reregister.
   Clock::resume();
   AWAIT_READY(slaveReregisteredMessage);
 }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/persistent_volume_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/persistent_volume_tests.cpp 
b/src/tests/persistent_volume_tests.cpp
index 4cb2c95..924d845 100644
--- a/src/tests/persistent_volume_tests.cpp
+++ b/src/tests/persistent_volume_tests.cpp
@@ -2186,7 +2186,7 @@ TEST_P(PersistentVolumeTest, SlaveRecovery)
 
   Clock::resume();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // The framework should not receive a TASK_FAILED here since the

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/slave_recovery_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/slave_recovery_tests.cpp 
b/src/tests/slave_recovery_tests.cpp
index 5a3f19f..c856752 100644
--- a/src/tests/slave_recovery_tests.cpp
+++ b/src/tests/slave_recovery_tests.cpp
@@ -717,7 +717,7 @@ TYPED_TEST(SlaveRecoveryTest, 
DISABLED_ROOT_CGROUPS_ReconnectDefaultExecutor)
 
 // The slave is stopped before the first update for a task is received
 // from the executor. When it comes back up with recovery=reconnect, make
-// sure the executor re-registers and the slave properly sends the update.
+// sure the executor reregisters and the slave properly sends the update.
 TYPED_TEST(SlaveRecoveryTest, ReconnectExecutor)
 {
   Try<Owned<cluster::Master>> master = this->StartMaster();
@@ -793,7 +793,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconnectExecutor)
   slave = this->StartSlave(detector.get(), containerizer.get(), flags);
   ASSERT_SOME(slave);
 
-  // Ensure the executor re-registers.
+  // Ensure the executor reregisters.
   AWAIT_READY(reregister);
 
   // Executor should inform about the unacknowledged updates.
@@ -893,7 +893,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconnectExecutorRetry)
   slave = this->StartSlave(detector.get(), containerizer.get(), flags);
   ASSERT_SOME(slave);
 
-  // The first attempt by the executor to re-register is dropped
+  // The first attempt by the executor to reregister is dropped
   // so that the agent will retry the reconnect.
   AWAIT_READY(reregisterExecutorMessage);
 
@@ -906,7 +906,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconnectExecutorRetry)
   AWAIT_READY(reregisterExecutorMessage);
 
   // Now ensure that further retries do not occur, since the
-  // executor is already re-registered.
+  // executor is already reregistered.
   EXPECT_NO_FUTURE_PROTOBUFS(ReregisterExecutorMessage(), _, _);
 
   Clock::advance(flags.executor_reregistration_retry_interval.get());
@@ -927,7 +927,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconnectExecutorRetry)
 // re-registration timeout to a duration longer than (agent_ping_timeout *
 // (max_agent_ping_timeouts + 1)), and then confirming that the agent is not
 // marked unreachable after the max ping timeout has elapsed, even if all
-// executors have re-registered. Agent recovery currently does not complete
+// executors have reregistered. Agent recovery currently does not complete
 // until the executor re-registration timeout has elapsed (see MESOS-7539).
 TYPED_TEST(SlaveRecoveryTest, PingTimeoutDuringRecovery)
 {
@@ -938,7 +938,7 @@ TYPED_TEST(SlaveRecoveryTest, PingTimeoutDuringRecovery)
   Try<Owned<cluster::Master>> master = this->StartMaster(masterFlags);
   ASSERT_SOME(master);
 
-  // Set the executor re-register timeout to a value greater than
+  // Set the executor reregister timeout to a value greater than
   // (agent_ping_timeout * (max_agent_ping_timeouts + 1)).
   slave::Flags slaveFlags = this->CreateSlaveFlags();
   slaveFlags.executor_reregistration_timeout = process::TEST_AWAIT_TIMEOUT;
@@ -1023,7 +1023,7 @@ TYPED_TEST(SlaveRecoveryTest, PingTimeoutDuringRecovery)
       slaveFlags);
   ASSERT_SOME(slave);
 
-  // Ensure the executor re-registers.
+  // Ensure the executor reregisters.
   AWAIT_READY(reregisterExecutor);
 
   Clock::pause();
@@ -1065,10 +1065,10 @@ TYPED_TEST(SlaveRecoveryTest, PingTimeoutDuringRecovery)
   ASSERT_EQ(TaskStatus::SOURCE_MASTER, statusUpdate2->source());
   ASSERT_EQ(TaskStatus::REASON_RECONCILIATION, statusUpdate2->reason());
 
-  // Ensure that the agent has not re-registered yet.
+  // Ensure that the agent has not reregistered yet.
   ASSERT_TRUE(reregisterSlave.isPending());
 
-  // Advance the clock to prompt the agent to re-register.
+  // Advance the clock to prompt the agent to reregister.
   Clock::pause();
   Clock::advance(slaveFlags.executor_reregistration_timeout);
   Clock::resume();
@@ -1995,7 +1995,7 @@ TYPED_TEST(SlaveRecoveryTest, 
DISABLED_CleanupHTTPExecutor)
 
   slave.get()->terminate();
 
-  // Slave in cleanup mode shouldn't re-register with the master and
+  // Slave in cleanup mode shouldn't reregister with the master and
   // hence no offers should be made by the master.
   EXPECT_CALL(sched, resourceOffers(_, _))
     .Times(0);
@@ -2119,7 +2119,7 @@ TYPED_TEST(SlaveRecoveryTest, CleanupExecutor)
 
   slave.get()->terminate();
 
-  // Slave in cleanup mode shouldn't re-register with the master and
+  // Slave in cleanup mode shouldn't reregister with the master and
   // hence no offers should be made by the master.
   EXPECT_CALL(sched, resourceOffers(_, _))
     .Times(0);
@@ -2465,7 +2465,7 @@ TYPED_TEST(SlaveRecoveryTest, 
DISABLED_KillTaskWithHTTPExecutor)
   // Wait for the executor to subscribe again.
   AWAIT_READY(subscribeCall);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<TaskStatus> status;
@@ -2585,14 +2585,14 @@ TYPED_TEST(SlaveRecoveryTest, KillTask)
 
   Clock::pause();
 
-  // Wait for the executor to re-register.
+  // Wait for the executor to reregister.
   AWAIT_READY(reregisterExecutorMessage);
 
   // Ensure the slave considers itself recovered.
   Clock::advance(flags.executor_reregistration_timeout);
   Clock::resume();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<TaskStatus> status;
@@ -3142,7 +3142,7 @@ TYPED_TEST(SlaveRecoveryTest, GCExecutor)
 
 
 // The slave is asked to shutdown. When it comes back up, it should
-// re-register as the same agent.
+// reregister as the same agent.
 TYPED_TEST(SlaveRecoveryTest, ShutdownSlave)
 {
   Try<Owned<cluster::Master>> master = this->StartMaster();
@@ -3599,7 +3599,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconcileKillTask)
 }
 
 
-// This test verifies that when the slave recovers and re-registers
+// This test verifies that when the slave recovers and reregisters
 // with a framework that was shutdown when the slave was down, it gets
 // a ShutdownFramework message.
 TYPED_TEST(SlaveRecoveryTest, ReconcileShutdownFramework)
@@ -3800,7 +3800,7 @@ TYPED_TEST(SlaveRecoveryTest, 
ReconcileTasksMissingFromSlave)
 
   // Start a task on the slave so that the master has knowledge of it.
   // We'll ensure the slave does not have this task when it
-  // re-registers by wiping the relevant meta directory.
+  // reregisters by wiping the relevant meta directory.
   TaskInfo task = createTask(offers1.get()[0], SLEEP_COMMAND(10));
 
   Future<TaskStatus> starting;
@@ -3901,7 +3901,7 @@ TYPED_TEST(SlaveRecoveryTest, 
ReconcileTasksMissingFromSlave)
 
   AWAIT_READY(_recover);
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // Wait for TASK_DROPPED update.
@@ -4043,14 +4043,14 @@ TYPED_TEST(SlaveRecoveryTest, SchedulerFailover)
 
   Clock::pause();
 
-  // Wait for the executor to re-register.
+  // Wait for the executor to reregister.
   AWAIT_READY(reregisterExecutorMessage);
 
   // Ensure the slave considers itself recovered.
   Clock::advance(flags.executor_reregistration_timeout);
   Clock::resume();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<TaskStatus> status;
@@ -4198,14 +4198,14 @@ TYPED_TEST_TEMP_DISABLED_ON_WINDOWS(SlaveRecoveryTest, 
MasterFailover)
 
   Clock::pause();
 
-  // Wait for the executor to re-register.
+  // Wait for the executor to reregister.
   AWAIT_READY(reregisterExecutorMessage);
 
   // Ensure the slave considers itself recovered.
   Clock::advance(flags.executor_reregistration_timeout);
   Clock::resume();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   Future<TaskStatus> status;
@@ -4367,7 +4367,7 @@ TYPED_TEST(SlaveRecoveryTest, MultipleFrameworks)
 
   Clock::pause();
 
-  // Wait for the executors to re-register.
+  // Wait for the executors to reregister.
   AWAIT_READY(reregisterExecutorMessage1);
   AWAIT_READY(reregisterExecutorMessage2);
 
@@ -4375,7 +4375,7 @@ TYPED_TEST(SlaveRecoveryTest, MultipleFrameworks)
   Clock::advance(flags.executor_reregistration_timeout);
   Clock::resume();
 
-  // Wait for the slave to re-register.
+  // Wait for the slave to reregister.
   AWAIT_READY(slaveReregisteredMessage);
 
   // Expectations for the status changes as a result of killing the
@@ -4567,7 +4567,7 @@ TYPED_TEST(SlaveRecoveryTest, MultipleSlaves)
   Clock::advance(flags1.executor_reregistration_timeout);
   Clock::resume();
 
-  // Wait for the slaves to re-register.
+  // Wait for the slaves to reregister.
   AWAIT_READY(slaveReregisteredMessage1);
   AWAIT_READY(slaveReregisteredMessage2);
 
@@ -5110,7 +5110,7 @@ TEST_F(MesosContainerizerSlaveRecoveryTest, 
ResourceStatistics)
   slave.get()->terminate();
 
   // Set up so we can wait until the new slave updates the container's
-  // resources (this occurs after the executor has re-registered).
+  // resources (this occurs after the executor has reregistered).
   Future<Nothing> update =
     FUTURE_DISPATCH(_, &MesosContainerizerProcess::update);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/slave_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/slave_tests.cpp b/src/tests/slave_tests.cpp
index e253317..c2afaa5 100644
--- a/src/tests/slave_tests.cpp
+++ b/src/tests/slave_tests.cpp
@@ -2842,7 +2842,7 @@ TEST_F(SlaveTest, ContainersEndpoint)
 
 
 // This test ensures that when a slave is shutting down, it will not
-// try to re-register with the master.
+// try to reregister with the master.
 TEST_F(SlaveTest, DISABLED_TerminatingSlaveDoesNotReregister)
 {
   // Start a master.
@@ -3283,7 +3283,7 @@ TEST_F(SlaveTest, TaskLaunchContainerizerUpdateFails)
 }
 
 
-// This test ensures that the slave will re-register with the master
+// This test ensures that the slave will reregister with the master
 // if it does not receive any pings after registering.
 TEST_F(SlaveTest, PingTimeoutNoPings)
 {
@@ -3338,7 +3338,7 @@ TEST_F(SlaveTest, PingTimeoutNoPings)
 }
 
 
-// This test ensures that the slave will re-register with the master
+// This test ensures that the slave will reregister with the master
 // if it stops receiving pings.
 TEST_F(SlaveTest, PingTimeoutSomePings)
 {
@@ -4221,7 +4221,7 @@ TEST_F(SlaveTest, KillMultiplePendingTasks)
   ASSERT_FALSE(offers->empty());
 
   // We only pause the clock after receiving the offer since the
-  // agent uses a delay to re-register.
+  // agent uses a delay to reregister.
   //
   // TODO(bmahler): Remove the initial agent delay within the tests.
   Clock::pause();
@@ -5512,7 +5512,7 @@ TEST_F_TEMP_DISABLED_ON_WINDOWS(SlaveTest,
 }
 
 
-// This test verifies that when a slave re-registers with the master
+// This test verifies that when a slave reregisters with the master
 // it correctly includes the latest and status update task states.
 TEST_F(SlaveTest, ReregisterWithStatusUpdateTaskState)
 {
@@ -6662,10 +6662,10 @@ TEST_F(SlaveTest, HTTPSchedulerSlaveRestart)
   slave = StartSlave(detector.get(), containerizer.get(), flags);
   ASSERT_SOME(slave);
 
-  // Let the executor re-register.
+  // Let the executor reregister.
   AWAIT_READY(reregisterExecutorMessage);
 
-  // Ensure the slave considers itself recovered and re-registers.
+  // Ensure the slave considers itself recovered and reregisters.
   Clock::settle();
   Clock::advance(flags.executor_reregistration_timeout);
 
@@ -8691,7 +8691,7 @@ TEST_F(SlaveTest, MaxCompletedExecutorsPerFrameworkFlag)
 
 
 // This ensures that if the executor reconnect retry is disabled,
-// PID-based V0 executors are disallowed from re-registering in
+// PID-based V0 executors are disallowed from reregistering in
 // the steady state.
 //
 // TODO(bmahler): It should be simpler to write a test that
@@ -9213,7 +9213,7 @@ TEST_F(SlaveTest, DisconnectedExecutorDropsMessages)
 
 
 // This test verifies that the 'executor_reregistration_timeout' agent flag
-// successfully extends the timeout within which an executor can re-register.
+// successfully extends the timeout within which an executor can reregister.
 TEST_F(SlaveTest, ExecutorReregistrationTimeoutFlag)
 {
   Clock::pause();
@@ -9222,7 +9222,7 @@ TEST_F(SlaveTest, ExecutorReregistrationTimeoutFlag)
   Try<Owned<cluster::Master>> master = StartMaster(masterFlags);
   ASSERT_SOME(master);
 
-  // Set the executor re-register timeout to a value greater than the default.
+  // Set the executor reregister timeout to a value greater than the default.
   slave::Flags slaveFlags = CreateSlaveFlags();
   slaveFlags.executor_reregistration_timeout = process::TEST_AWAIT_TIMEOUT;
 
@@ -9306,7 +9306,7 @@ TEST_F(SlaveTest, ExecutorReregistrationTimeoutFlag)
   slave = StartSlave(detector.get(), containerizer.get(), slaveFlags);
   ASSERT_SOME(slave);
 
-  // Ensure that the executor attempts to re-register, so that we can capture
+  // Ensure that the executor attempts to reregister, so that we can capture
   // its re-registration message.
   AWAIT_READY(reregisterExecutor);
 
@@ -9319,9 +9319,9 @@ TEST_F(SlaveTest, ExecutorReregistrationTimeoutFlag)
   // Send the executor's delayed re-registration message.
   process::post(slave.get()->pid, reregisterExecutor.get());
 
-  // Advance the clock to prompt the agent to re-register, and ensure that the
+  // Advance the clock to prompt the agent to reregister, and ensure that the
   // executor's task would have been marked unreachable if the executor had not
-  // re-registered successfully.
+  // reregistered successfully.
   Clock::advance(slaveFlags.executor_reregistration_timeout * 0.2);
 
   Clock::resume();
@@ -9905,7 +9905,7 @@ TEST_F(SlaveTest, ResourceVersions)
     FUTURE_PROTOBUF(ReregisterSlaveMessage(), _, _);
 
   // Simulate a new master detected event on the slave,
-  // so that the slave will attempt to re-register.
+  // so that the slave will attempt to reregister.
   detector.appoint(master.get()->pid);
 
   Clock::settle();

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/storage_local_resource_provider_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/storage_local_resource_provider_tests.cpp 
b/src/tests/storage_local_resource_provider_tests.cpp
index c2fcbf3..264d42b 100644
--- a/src/tests/storage_local_resource_provider_tests.cpp
+++ b/src/tests/storage_local_resource_provider_tests.cpp
@@ -3061,7 +3061,7 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_Metrics)
 }
 
 
-// Master reconciles operations that are missing from a re-registering slave.
+// Master reconciles operations that are missing from a reregistering slave.
 // In this case, the `ApplyOperationMessage` is dropped, so the resource
 // provider should send OPERATION_DROPPED. Operations on agent default
 // resources are also tested here; for such operations, the agent generates the

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/teardown_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/teardown_tests.cpp b/src/tests/teardown_tests.cpp
index 392cacf..e427ef4 100644
--- a/src/tests/teardown_tests.cpp
+++ b/src/tests/teardown_tests.cpp
@@ -321,7 +321,7 @@ TEST_F(TeardownTest, NoHeader)
 
 
 // This test checks that the teardown operation can be used on a
-// framework that has not re-registered after master failover.
+// framework that has not reregistered after master failover.
 TEST_F(TeardownTest, RecoveredFrameworkAfterMasterFailover)
 {
   master::Flags masterFlags = CreateMasterFlags();
@@ -380,7 +380,7 @@ TEST_F(TeardownTest, RecoveredFrameworkAfterMasterFailover)
   AWAIT_READY(statusUpdateAck2);
 
   // Simulate master failover. We leave the scheduler without a master
-  // so it does not attempt to re-register.
+  // so it does not attempt to reregister.
   EXPECT_CALL(sched, disconnected(&driver));
 
   schedDetector.appoint(None());
@@ -397,7 +397,7 @@ TEST_F(TeardownTest, RecoveredFrameworkAfterMasterFailover)
 
   AWAIT_READY(slaveReregisteredMessage);
 
-  // Teardown the framework, which has not yet re-registered with the
+  // Teardown the framework, which has not yet reregistered with the
   // new master.
   {
     Future<Response> response = process::http::post(

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/tests/upgrade_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/upgrade_tests.cpp b/src/tests/upgrade_tests.cpp
index dd73d73..491ace5 100644
--- a/src/tests/upgrade_tests.cpp
+++ b/src/tests/upgrade_tests.cpp
@@ -88,7 +88,7 @@ class UpgradeTest : public MesosTest {};
 
 
 // This tests that when a non-MULTI_ROLE agent with task running
-// re-registers with MULTI_ROLE master, master will inject the
+// reregisters with MULTI_ROLE master, master will inject the
 // allocation role in the tasks and executors.
 //
 // Firstly we start a regular MULTI_ROLE agent and launch a long
@@ -165,7 +165,7 @@ TEST_F(UpgradeTest, ReregisterOldAgentWithMultiRoleMaster)
   master = StartMaster(masterFlags);
   ASSERT_SOME(master);
 
-  // Cause the scheduler to re-register with the master.
+  // Cause the scheduler to reregister with the master.
   Future<Nothing> disconnected;
   EXPECT_CALL(sched, disconnected(&driver))
     .WillOnce(FutureSatisfy(&disconnected));

Reply via email to
diff --git a/src/slave/slave.cpp b/src/slave/slave.cpp
index 8cb6899..2f4ab15 100644
--- a/src/slave/slave.cpp
+++ b/src/slave/slave.cpp
@@ -1511,7 +1511,7 @@ void Slave::registered(
       // running, so the resource providers can use the agent API.
       localResourceProviderDaemon->start(info.id());
 
       // Setup a timer so that the agent attempts to re-register if it
       // doesn't receive a ping from the master for an extended period
       // of time. This needs to be done once registered, in case we
       // never receive an initial ping.
@@ -1595,9 +1595,9 @@ void Slave::reregistered(
       // running, so the resource providers can use the agent API.
       localResourceProviderDaemon->start(info.id());
 
       // Setup a timer so that the agent attempts to re-register if it
       // doesn't receive a ping from the master for an extended period
       // of time. This needs to be done once re-registered, in case we
       // never receive an initial ping.
       Clock::cancel(pingTimer);
 
@@ -1609,7 +1609,7 @@ void Slave::reregistered(
 
       break;
     case RUNNING:
-      LOG(WARNING) << "Already re-registered with master " << master.get();
+      LOG(WARNING) << "Already reregistered with master " << master.get();
       break;
     case TERMINATING:
       LOG(WARNING) << "Ignoring re-registration because agent is terminating";
@@ -1805,7 +1805,7 @@ void Slave::doReliableRegistration(Duration maxBackoff)
               task, TASK_STAGING, framework->id()));
         }
 
         // Do not re-register with Command (or Docker) Executors
         // because the master doesn't store them; they are generated
         // by the slave.
         if (!executor->isGeneratedForCommandTask()) {
@@ -3377,7 +3377,7 @@ void Slave::launchExecutor(
   ExecutorInfo executorInfo_ = executor->info;
 
   // Populate the command info for default executor. We modify the ExecutorInfo
   // to avoid resetting command info upon re-registering with the master since
   // the master doesn't store them; they are generated by the slave.
   if (executorInfo_.has_type() &&
       executorInfo_.type() == ExecutorInfo::DEFAULT) {
@@ -4962,14 +4962,14 @@ void Slave::reregisterExecutor(
       } else {
         // When the agent is configured to retry the reconnect requests
         // to executors, we ignore any further re-registrations. This
         // is because we can't easily handle re-registering libprocess
         // based executors in the steady state, and we plan to move to
         // only allowing v1 HTTP executors (where re-subscription in
         // the steady state is supported). Also, ignoring this message
         // ensures that any executors mimicking the libprocess protocol
         // do not have any illusion of being able to re-register without
         // an agent restart (hopefully they will commit suicide if they
-        // fail to re-register).
+        // fail to reregister).
         LOG(WARNING) << "Ignoring executor re-registration message from "
                      << *executor << " because it is already registered";
       }
@@ -5061,7 +5061,7 @@ void Slave::reregisterExecutor(
       // self terminating logic when they haven't received the task or
       // task group within a timeout.
       if (!executor->everSentTask() && executor->queuedTasks.empty()) {
-        LOG(WARNING) << "Shutting down re-registering executor " << *executor
+        LOG(WARNING) << "Shutting down reregistering executor " << *executor
                      << " because it has no tasks to run and"
                      << " has never been sent a task";
 
@@ -5132,7 +5132,7 @@ void Slave::reregisterExecutorTimeout()
 
     foreachvalue (Executor* executor, framework->executors) {
       switch (executor->state) {
-        case Executor::RUNNING:     // Executor re-registered.
+        case Executor::RUNNING:     // Executor reregistered.
         case Executor::TERMINATING:
         case Executor::TERMINATED:
           break;
@@ -5162,7 +5162,7 @@ void Slave::reregisterExecutorTimeout()
           termination.set_reason(
               TaskStatus::REASON_EXECUTOR_REREGISTRATION_TIMEOUT);
           termination.set_message(
-              "Executor did not re-register within " +
+              "Executor did not reregister within " +
               stringify(flags.executor_reregistration_timeout));
 
           executor->pendingTermination = termination;
@@ -5323,7 +5323,7 @@ void Slave::statusUpdate(StatusUpdate update, const 
Option<UPID>& pid)
     // ACK to the executor AND 2) after recovery the status update
     // manager successfully retried the update, got the ACK from the
     // scheduler and cleaned up the stream before the executor
     // re-registered. In this case, the slave cannot find the executor
     // corresponding to this task because the task has been moved to
     // 'Executor::completedTasks'.
     //
@@ -5670,7 +5670,7 @@ void Slave::forward(StatusUpdate update)
         // We set the status update state of the task here because in
         // steady state master updates the status update state of the
         // task when it receives this update. If the master fails over,
-        // slave re-registers with this task in this status update
+        // slave reregisters with this task in this status update
         // state. Note that an acknowledgement for this update might be
         // enqueued on task status update manager when we are here. But
         // that is ok because the status update state will be updated
@@ -5773,7 +5773,7 @@ void Slave::executorMessage(
 // longer than the master's ping timeout. We don't want to cause
 // cluster churn by marking such agents unreachable. If the master
 // sees a broken agent socket, it waits `agent_reregister_timeout` for
 // the agent to re-register, which implies that recovery should finish
 // within that (more generous) timeout.
 void Slave::ping(const UPID& from, bool connected)
 {
@@ -7180,7 +7180,7 @@ Future<Nothing> Slave::_recover()
           &Slave::reregisterExecutorTimeout);
 
     // We set 'recovered' flag inside reregisterExecutorTimeout(),
-    // so that when the slave re-registers with master it can
+    // so that when the slave reregisters with master it can
     // correctly inform the master about the launched tasks.
     return recoveryInfo.recovered.future();
   }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/slave.hpp
----------------------------------------------------------------------
@@ -1511,7 +1511,7 @@ void Slave::registered(
       localResourceProviderDaemon->start(info.id());
 
-      // Setup a timer so that the agent attempts to re-register if it
+      // Setup a timer so that the agent attempts to reregister if it
       // doesn't receive a ping from the master for an extended period
       // of time. This needs to be done once registered, in case we
@@ -1595,9 +1595,9 @@ void Slave::reregistered(
       localResourceProviderDaemon->start(info.id());
 
-      // Setup a timer so that the agent attempts to re-register if it
+      // Setup a timer so that the agent attempts to reregister if it
       // doesn't receive a ping from the master for an extended period
@@ -1595,9 +1595,9 @@ void Slave::reregistered(
       // doesn't receive a ping from the master for an extended period
-      // of time. This needs to be done once re-registered, in case we
+      // of time. This needs to be done once reregistered, in case we
       // never receive an initial ping.
       Clock::cancel(pingTimer);
@@ -1805,7 +1805,7 @@ void Slave::doReliableRegistration(Duration maxBackoff)
         }
 
-        // Do not re-register with Command (or Docker) Executors
+        // Do not reregister with Command (or Docker) Executors
         // because the master doesn't store them; they are generated
         // by the slave.
@@ -3377,7 +3377,7 @@ void Slave::launchExecutor(
 
   // Populate the command info for default executor. We modify the ExecutorInfo
-  // to avoid resetting command info upon re-registering with the master since
+  // to avoid resetting command info upon reregistering with the master since
   // the master doesn't store them; they are generated by the slave.
   if (executorInfo_.has_type() &&
@@ -4962,14 +4962,14 @@ void Slave::reregisterExecutor(
         // When the agent is configured to retry the reconnect requests
         // to executors, we ignore any further re-registrations. This
-        // is because we can't easily handle re-registering libprocess
+        // is because we can't easily handle reregistering libprocess
         // based executors in the steady state, and we plan to move to
         // only allowing v1 HTTP executors (where re-subscription in
@@ -4962,14 +4962,14 @@ void Slave::reregisterExecutor(
         // the steady state is supported). Also, ignoring this message
         // ensures that any executors mimicking the libprocess protocol
-        // do not have any illusion of being able to re-register without
+        // do not have any illusion of being able to reregister without
         // an agent restart (hopefully they will commit suicide if they
@@ -5323,7 +5323,7 @@ void Slave::statusUpdate(StatusUpdate update, const 
     // manager successfully retried the update, got the ACK from the
     // scheduler and cleaned up the stream before the executor
-    // re-registered. In this case, the slave cannot find the executor
+    // reregistered. In this case, the slave cannot find the executor
     // corresponding to this task because the task has been moved to
     // 'Executor::completedTasks'.
@@ -5773,7 +5773,7 @@ void Slave::executorMessage(
 // cluster churn by marking such agents unreachable. If the master
 // sees a broken agent socket, it waits `agent_reregister_timeout` for
-// the agent to re-register, which implies that recovery should finish
+// the agent to reregister, which implies that recovery should finish
 // within that (more generous) timeout.
 void Slave::ping(const UPID& from, bool connected)